==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatement;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.EventSpecificationStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.List;


public class GenerateEventStatementSetImpl extends InstanceSet<GenerateEventStatementSet,GenerateEventStatement> implements GenerateEventStatementSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateEventStatement generateeventstatement : this ) generateeventstatement.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public EventSpecificationStatementSet R701_is_a_EventSpecificationStatement() throws XtumlException {
        EventSpecificationStatementSet eventspecificationstatementset = new EventSpecificationStatementSetImpl();
        for ( GenerateEventStatement generateeventstatement : this ) eventspecificationstatementset.add( generateeventstatement.R701_is_a_EventSpecificationStatement() );
        return eventspecificationstatementset;
    }
    @Override
    public GenerateSMEventStatementSet R703_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( GenerateEventStatement generateeventstatement : this ) generatesmeventstatementset.add( generateeventstatement.R703_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }


    @Override
    public GenerateEventStatement nullElement() {
        return GenerateEventStatementImpl.EMPTY_GENERATEEVENTSTATEMENT;
    }

    @Override
    public GenerateEventStatementSet emptySet() {
      return new GenerateEventStatementSetImpl();
    }

    @Override
    public GenerateEventStatementSet value() {
        return this;
    }

    @Override
    public List<GenerateEventStatement> elements() {
        return Arrays.asList(toArray(new GenerateEventStatement[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatement;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.EventSpecificationStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GenerateEventStatementSetImpl extends InstanceSet<GenerateEventStatementSet,GenerateEventStatement> implements GenerateEventStatementSet {

    public GenerateEventStatementSetImpl() {
    }

    public GenerateEventStatementSetImpl(Comparator<? super GenerateEventStatement> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateEventStatement generateeventstatement : this ) generateeventstatement.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public EventSpecificationStatementSet R701_is_a_EventSpecificationStatement() throws XtumlException {
        EventSpecificationStatementSet eventspecificationstatementset = new EventSpecificationStatementSetImpl();
        for ( GenerateEventStatement generateeventstatement : this ) eventspecificationstatementset.add( generateeventstatement.R701_is_a_EventSpecificationStatement() );
        return eventspecificationstatementset;
    }
    @Override
    public GenerateSMEventStatementSet R703_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( GenerateEventStatement generateeventstatement : this ) generatesmeventstatementset.add( generateeventstatement.R703_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }


    @Override
    public GenerateEventStatement nullElement() {
        return GenerateEventStatementImpl.EMPTY_GENERATEEVENTSTATEMENT;
    }

    @Override
    public GenerateEventStatementSet emptySet() {
      return new GenerateEventStatementSetImpl();
    }

    @Override
    public GenerateEventStatementSet emptySet(Comparator<? super GenerateEventStatement> comp) {
      return new GenerateEventStatementSetImpl(comp);
    }

    @Override
    public GenerateEventStatementSet value() {
        return this;
    }

    @Override
    public List<GenerateEventStatement> elements() {
        return Arrays.asList(toArray(new GenerateEventStatement[0]));
    }

}
